@@ -45,29 +45,33 @@
  * Helper Functions ***********************************************************
  ****************************************************************************/
 
+/* u2bytes converts an unsigned int to bytes, which are the big-endian
+   representation of this integer */
 static void u2bytes(unsigned in, char *out)
 {
     unsigned char *s = (unsigned char *)out;
 
-    s[0] = in & 0xFF;
-    s[1] = (in >> 8) & 0xFF;
-    s[2] = (in >> 16) & 0xFF;
-    s[3] = (in >> 24) & 0xFF;
+    s[0] = (in >> 24) & 0xFF;
+    s[1] = (in >> 16) & 0xFF;
+    s[2] = (in >> 8) & 0xFF;
+    s[3] = in & 0xFF;
     s[4] = '\0';
 }
 
+/* ull2bytes converts an unsigned long long to bytes, which are the big-endian
+   representation of this integer */
 static void ull2bytes(unsigned long long in, char *out)
 {
     unsigned char *s = (unsigned char *)out;
 
-    s[0] = in & 0xFF;
-    s[1] = (in >> 8) & 0xFF;
-    s[2] = (in >> 16) & 0xFF;
-    s[3] = (in >> 24) & 0xFF;
-    s[4] = (in >> 32) & 0xFF;
-    s[5] = (in >> 40) & 0xFF;
-    s[6] = (in >> 48) & 0xFF;
-    s[7] = (in >> 56) & 0xFF;
+    s[0] = (in >> 56) & 0xFF;
+    s[1] = (in >> 48) & 0xFF;
+    s[2] = (in >> 40) & 0xFF;
+    s[3] = (in >> 32) & 0xFF;
+    s[4] = (in >> 24) & 0xFF;
+    s[5] = (in >> 16) & 0xFF;
+    s[6] = (in >> 8) & 0xFF;
+    s[7] = in & 0xFF;
     s[8] = '\0';
 }
 
@@ -242,7 +246,7 @@ static PyObject *PYXXH32_hexdigest(PYXXH32Object *self)
 
 PyDoc_STRVAR(
     PYXXH32_intdigest_doc,
-    "hexdigest() -> int\n\n"
+    "intdigest() -> int\n\n"
     "Like digest(), but returns the digest as an integer, which is the integer\n"
     "returned by xxhash C API");
 
@@ -271,12 +275,24 @@ static PyObject *PYXXH32_copy(PYXXH32Object *self)
     return (PyObject *)p;
 }
 
+PyDoc_STRVAR(
+    PYXXH32_reset_doc,
+    "reset()\n\n"
+    "Reset state.");
+
+static PyObject *PYXXH32_reset(PYXXH32Object *self)
+{
+    XXH32_reset(self->xxhash_state, self->seed);
+    Py_RETURN_NONE;
+}
+
 static PyMethodDef PYXXH32_methods[] = {
     {"update", (PyCFunction)PYXXH32_update, METH_VARARGS, PYXXH32_update_doc},
     {"digest", (PyCFunction)PYXXH32_digest, METH_NOARGS, PYXXH32_digest_doc},
     {"hexdigest", (PyCFunction)PYXXH32_hexdigest, METH_NOARGS, PYXXH32_hexdigest_doc},
     {"intdigest", (PyCFunction)PYXXH32_intdigest, METH_NOARGS, PYXXH32_intdigest_doc},
     {"copy", (PyCFunction)PYXXH32_copy, METH_NOARGS, PYXXH32_copy_doc},
+    {"reset", (PyCFunction)PYXXH32_reset, METH_NOARGS, PYXXH32_reset_doc},
     {NULL, NULL, 0, NULL}
 };
 
@@ -356,7 +372,7 @@ PyDoc_STRVAR(
 
 static PyTypeObject PYXXH32Type = {
 #if PY_MAJOR_VERSION >= 3
-    PyVarObject_HEAD_INIT(&PyType_Type, 0)
+    PyVarObject_HEAD_INIT(NULL, 0)
 #else
     PyObject_HEAD_INIT(NULL)
     0,                             /* ob_size */
@@ -566,7 +582,7 @@ static PyObject *PYXXH64_hexdigest(PYXXH64Object *self)
 
 PyDoc_STRVAR(
     PYXXH64_intdigest_doc,
-    "hexdigest() -> int\n\n"
+    "intdigest() -> int\n\n"
     "Like digest(), but returns the digest as an integer, which is the integer\n"
     "returned by xxhash C API");
 
@@ -595,12 +611,24 @@ static PyObject *PYXXH64_copy(PYXXH64Object *self)
     return (PyObject *)p;
 }
 
+PyDoc_STRVAR(
+    PYXXH64_reset_doc,
+    "reset()\n\n"
+    "Reset state.");
+
+static PyObject *PYXXH64_reset(PYXXH64Object *self)
+{
+    XXH64_reset(self->xxhash_state, self->seed);
+    Py_RETURN_NONE;
+}
+
 static PyMethodDef PYXXH64_methods[] = {
     {"update", (PyCFunction)PYXXH64_update, METH_VARARGS, PYXXH64_update_doc},
     {"digest", (PyCFunction)PYXXH64_digest, METH_NOARGS, PYXXH64_digest_doc},
     {"hexdigest", (PyCFunction)PYXXH64_hexdigest, METH_NOARGS, PYXXH64_hexdigest_doc},
     {"intdigest", (PyCFunction)PYXXH64_intdigest, METH_NOARGS, PYXXH64_intdigest_doc},
     {"copy", (PyCFunction)PYXXH64_copy, METH_NOARGS, PYXXH64_copy_doc},
+    {"reset", (PyCFunction)PYXXH64_reset, METH_NOARGS, PYXXH64_reset_doc},
     {NULL, NULL, 0, NULL}
 };
 
@@ -680,7 +708,7 @@ PyDoc_STRVAR(
 
 static PyTypeObject PYXXH64Type = {
 #if PY_MAJOR_VERSION >= 3
-    PyVarObject_HEAD_INIT(&PyType_Type, 0)
+    PyVarObject_HEAD_INIT(NULL, 0)
 #else
     PyObject_HEAD_INIT(NULL)
     0,                             /* ob_size */
